#include "settings.h"
#include "settings.moc"

#include <qlabel.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <qwhatsthis.h>

#include <klocale.h>
#include <knuminput.h>
#include <kdialog.h>
#include <kglobal.h>


//-----------------------------------------------------------------------------
AppearanceConfig::AppearanceConfig()
{
    int row = _grid->numRows();
    int col = _grid->numCols();

    QCheckBox *cb = new QCheckBox(i18n("Show piece's shadow"), _main, "show piece shadow");
    cb->setChecked(true);
    _grid->addMultiCellWidget(cb, row, row, 0, col-1);

    cb = new QCheckBox(i18n("Show next piece"), _main, "show next piece");
    cb->setChecked(true);
    _grid->addMultiCellWidget(cb, row+1, row+1, 0, col-1);

    cb = new QCheckBox(i18n("Show detailed \"removed lines\" field"), _main, "show detailed removed");
    cb->setChecked(true);
    _grid->addMultiCellWidget(cb, row+2, row+2, 0, col-1);
}

bool AppearanceConfig::isNextPieceShown()
{
    ConfigGroupSaver cg;
    return cg.config()->readBoolEntry("show next piece", true);
}

bool AppearanceConfig::isPieceShadowShown()
{
    ConfigGroupSaver cg;
    return cg.config()->readBoolEntry("show piece shadow", true);
}

bool AppearanceConfig::isDetailedRemovedShown()
{
    ConfigGroupSaver cg;
    return cg.config()->readBoolEntry("show detailed removed", true);
}


//-----------------------------------------------------------------------------
GameConfig::GameConfig()
    : QWidget(0, "game config")
{
    QVBoxLayout *top = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());

    _grid = new QGridLayout(top, 3, 2);
    _grid->setColStretch(1, 1);

    QLabel *label = new QLabel(i18n("Initial level:"), this);
    _grid->addWidget(label, 0, 0);
    KIntNumInput *in = new KIntNumInput(this, "init level");
    in->setRange(1, 20);
    in->setValue(1);
    _grid->addWidget(in, 0, 1);

    _grid->addRowSpacing(1, KDialog::spacingHint());

    QCheckBox *cb = new QCheckBox(i18n("Direct drop down"), this, "direct drop down");
    QWhatsThis::add(cb, i18n("Drop down is not stopped when drop down key is released."));
    cb->setChecked(false);
    _grid->addMultiCellWidget(cb, 2, 2, 0, 1);

    top->addStretch(1);
}

uint GameConfig::initialLevel()
{
    ConfigGroupSaver cg;
    uint i = cg.config()->readUnsignedNumEntry("init level", 1);
    return kMax(uint(1), kMin(uint(20), i));
}

bool GameConfig::isDirectDropDownEnabled()
{
    ConfigGroupSaver cg;
    return cg.config()->readBoolEntry("direct drop down", false);
}
